Agent
=====

Ax Agent (Recommended)
----------------------

.. autoclass:: blop.ax.Agent
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :no-index:

Agent (Deprecated)
------------------

.. autoclass:: blop.agent.Agent
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :no-index:
